@@ -2,9 +2,9 @@
 # Author:        rpettett@cpan.org
 # Maintainer:    rpettett@cpan.org
 # Created:       2005-08-23
-# Last Modified: $Date: 2010/02/04 15:01:56 $ $Author: aj5 $
+# Last Modified: $Date: 2010-03-24 19:29:46 +0000 (Wed, 24 Mar 2010) $ $Author: zerojinx $
 # Source:        $Source: /var/lib/cvsd/cvsroot/Bio-DasLite/Bio-DasLite/lib/Bio/Das/Lite.pm,v $
-# Id:            $Id: Lite.pm,v 1.67 2010/02/04 15:01:56 aj5 Exp $
+# Id:            $Id: Lite.pm 19 2010-03-24 19:29:46Z zerojinx $
 # $HeadURL $
 #
 package Bio::Das::Lite;
@@ -19,10 +19,10 @@ use English qw(-no_match_vars);
 use Readonly;
 
 our $DEBUG    = 0;
-our $VERSION  = '2.02';
+our $VERSION  = '2.03';
 Readonly::Scalar our $TIMEOUT         => 5;
 Readonly::Scalar our $REG_TIMEOUT     => 15;
-Readonly::Scalar our $LINKRE          => qr{<link\s+href="([^"]+)"[^>]*?>([^<]*)</link>|<link\s+href="([^"]+)"[^>]*?/>}smix;
+Readonly::Scalar our $LINKRE          => qr{<link\s+href="([^"]+)"[^>]*?>([^<]*)</link>|<link\s+href="([^"]+)"[^>]*?/>}smix; ## no critic (ProhibitComplexRegexes)
 Readonly::Scalar our $NOTERE          => qr{<note[^>]*>([^<]*)</note>}smix;
 Readonly::Scalar our $DAS_STATUS_TEXT => {
 					  200 => '200 OK',
@@ -558,8 +558,8 @@ sub _generic_request {
   delete $self->{'currentsegs'};
   my $results   = {};
   my $reqname   = $fname;
-  $reqname      =~ s/[\(\)]//smxg;
-  ($fname)      = $fname =~ /^([a-z_]+)/smx;
+  $reqname      =~ s/(?:[(]|[)])//smxg;
+  ($fname)      = $fname =~ /^([[:lower:]_]+)/smx;
 
   my $ref       = $self->build_requests({
 					 query   => $query,
